@@ -27,8 +27,8 @@ References:
         of the adaptive quasi-harmonic model”, em IEEE International Conference
         on Acoustics, Speech and Signal Processing (ICASSP), 2012.
 
-Version 1.0.3
-23/Dec/2014 Bernardo J.B. Schmitt - bernardo.jb.schmitt@gmail.com
+Version 1.0.4
+13/Jan/2015 Bernardo J.B. Schmitt - bernardo.jb.schmitt@gmail.com
 """
 
 import numpy as np
